==> jc-1.4.0.tar.gz: javax/swing/event/ListDataEvent.h <==
// public class javax.swing.event.ListDataEvent

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class e4988e4c1a7050ab java_util_EventObject
// @dep_class 74c880dffa109b4f javax_swing_event_ListDataEvent

// header file dependencies
// @dep_header java_util_EventObject

#include "java/util/EventObject.h"

#ifndef _JC_javax_swing_event_ListDataEvent_H_
#define _JC_javax_swing_event_ListDataEvent_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;

// Typedefs
typedef struct _jc_javax_swing_event_ListDataEvent$sub_refs	_jc_javax_swing_event_ListDataEvent$sub_refs;
typedef struct _jc_javax_swing_event_ListDataEvent$sub_nonrefs	_jc_javax_swing_event_ListDataEvent$sub_nonrefs;
typedef struct _jc_javax_swing_event_ListDataEvent$refs	_jc_javax_swing_event_ListDataEvent$refs;
typedef struct _jc_javax_swing_event_ListDataEvent$nonrefs	_jc_javax_swing_event_ListDataEvent$nonrefs;
typedef struct _jc_javax_swing_event_ListDataEvent$object	_jc_javax_swing_event_ListDataEvent$object;

typedef struct _jc_javax_swing_event_ListDataEvent$fields_struct	_jc_javax_swing_event_ListDataEvent$fields_struct;
typedef const struct _jc_javax_swing_event_ListDataEvent$vmethods	_jc_javax_swing_event_ListDataEvent$vmethods;
typedef const struct _jc_javax_swing_event_ListDataEvent$vtable	_jc_javax_swing_event_ListDataEvent$vtable;
typedef const struct _jc_javax_swing_event_ListDataEvent$vtype	_jc_javax_swing_event_ListDataEvent$vtype;

// Class fields structure
struct _jc_javax_swing_event_ListDataEvent$fields_struct {
	jlong	serialVersionUID;
	jint	CONTENTS__5fCHANGED;
	jint	INTERVAL__5fADDED;
	jint	INTERVAL__5fREMOVED;
};
extern _jc_javax_swing_event_ListDataEvent$fields_struct _jc_javax_swing_event_ListDataEvent$class_fields;

// Constructors
extern void _jc_javax_swing_event_ListDataEvent$method$_init$0a28ad177533eb63(_jc_env *, struct _jc_javax_swing_event_ListDataEvent$object *, struct _jc_java_lang_Object$object *, jint, jint, jint);

// Virtual methods
extern jint _jc_javax_swing_event_ListDataEvent$method$getIndex0$4a2aa7bb16839fe6(_jc_env *, struct _jc_javax_swing_event_ListDataEvent$object *);
extern jint _jc_javax_swing_event_ListDataEvent$method$getIndex1$c76868da218ce41e(_jc_env *, struct _jc_javax_swing_event_ListDataEvent$object *);
extern jint _jc_javax_swing_event_ListDataEvent$method$getType$74c20eac6b18d047(_jc_env *, struct _jc_javax_swing_event_ListDataEvent$object *);
extern void _jc_javax_swing_event_ListDataEvent$method$this$adc93fb6bf4cbffa(_jc_env *, struct _jc_javax_swing_event_ListDataEvent$object *);

// Virtual method descriptors
extern _jc_method _jc_javax_swing_event_ListDataEvent$method_info$getIndex0$4a2aa7bb16839fe6;
extern _jc_method _jc_javax_swing_event_ListDataEvent$method_info$getIndex1$c76868da218ce41e;
extern _jc_method _jc_javax_swing_event_ListDataEvent$method_info$getType$74c20eac6b18d047;
extern _jc_method _jc_javax_swing_event_ListDataEvent$method_info$this$adc93fb6bf4cbffa;

// Virtual methods structure
struct _jc_javax_swing_event_ListDataEvent$vmethods {
	jint	(*getIndex0$4a2aa7bb16839fe6)(_jc_env *, struct _jc_javax_swing_event_ListDataEvent$object *);
	jint	(*getIndex1$c76868da218ce41e)(_jc_env *, struct _jc_javax_swing_event_ListDataEvent$object *);
	jint	(*getType$74c20eac6b18d047)(_jc_env *, struct _jc_javax_swing_event_ListDataEvent$object *);
	void	(*this$adc93fb6bf4cbffa)(_jc_env *, struct _jc_javax_swing_event_ListDataEvent$object *);
};

// Vtable
struct _jc_javax_swing_event_ListDataEvent$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_util_EventObject$vmethods	java_util_EventObject;
	_jc_javax_swing_event_ListDataEvent$vmethods	javax_swing_event_ListDataEvent;
};

// Vtype
struct _jc_javax_swing_event_ListDataEvent$vtype {
	_jc_type			type;
	_jc_javax_swing_event_ListDataEvent$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_swing_event_ListDataEvent$sub_refs {
};

// Reference instance fields (object)
struct _jc_javax_swing_event_ListDataEvent$refs {
    _jc_javax_swing_event_ListDataEvent$sub_refs	javax_swing_event_ListDataEvent;
    _jc_java_util_EventObject$sub_refs	java_util_EventObject;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_swing_event_ListDataEvent$sub_nonrefs {
	jint	type;
	jint	index0;
	jint	index1;
};

// Non-reference instance fields (object)
struct _jc_javax_swing_event_ListDataEvent$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_util_EventObject$sub_nonrefs	java_util_EventObject;
    _jc_javax_swing_event_ListDataEvent$sub_nonrefs	javax_swing_event_ListDataEvent;
};

// Object instance structure
struct _jc_javax_swing_event_ListDataEvent$object {
	_jc_javax_swing_event_ListDataEvent$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_swing_event_ListDataEvent$vtype	*vtype;
	_jc_javax_swing_event_ListDataEvent$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_swing_event_ListDataEvent$vtype _jc_javax_swing_event_ListDataEvent$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_swing_event_ListDataEvent, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_swing_event_ListDataEvent$class_object;

#endif	/* _JC_javax_swing_event_ListDataEvent_H_ */

==> jc-1.4.6.tar.gz: javax/swing/event/ListDataEvent.h <==
// public class javax.swing.event.ListDataEvent

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class e4988e4c1a7050ab java_util_EventObject
// @dep_class 74c880dffa109b4f javax_swing_event_ListDataEvent

// header file dependencies
// @dep_header java_util_EventObject

#include "java/util/EventObject.h"

#ifndef _JC_javax_swing_event_ListDataEvent_H_
#define _JC_javax_swing_event_ListDataEvent_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;

// Typedefs
typedef struct _jc_javax_swing_event_ListDataEvent$sub_refs	_jc_javax_swing_event_ListDataEvent$sub_refs;
typedef struct _jc_javax_swing_event_ListDataEvent$sub_nonrefs	_jc_javax_swing_event_ListDataEvent$sub_nonrefs;
typedef struct _jc_javax_swing_event_ListDataEvent$refs	_jc_javax_swing_event_ListDataEvent$refs;
typedef struct _jc_javax_swing_event_ListDataEvent$nonrefs	_jc_javax_swing_event_ListDataEvent$nonrefs;
typedef struct _jc_javax_swing_event_ListDataEvent$object	_jc_javax_swing_event_ListDataEvent$object;

typedef struct _jc_javax_swing_event_ListDataEvent$fields_struct	_jc_javax_swing_event_ListDataEvent$fields_struct;
typedef const struct _jc_javax_swing_event_ListDataEvent$vmethods	_jc_javax_swing_event_ListDataEvent$vmethods;
typedef const struct _jc_javax_swing_event_ListDataEvent$vtable	_jc_javax_swing_event_ListDataEvent$vtable;
typedef const struct _jc_javax_swing_event_ListDataEvent$vtype	_jc_javax_swing_event_ListDataEvent$vtype;

// Class fields structure
struct _jc_javax_swing_event_ListDataEvent$fields_struct {
	jlong	serialVersionUID;
	jint	CONTENTS__5fCHANGED;
	jint	INTERVAL__5fADDED;
	jint	INTERVAL__5fREMOVED;
};
extern _jc_javax_swing_event_ListDataEvent$fields_struct _jc_javax_swing_event_ListDataEvent$class_fields;

// Constructors
extern void _jc_javax_swing_event_ListDataEvent$method$_init$0a28ad177533eb63(_jc_env *, struct _jc_javax_swing_event_ListDataEvent$object *, struct _jc_java_lang_Object$object *, jint, jint, jint) _JC_JCNI_ATTR;

// Virtual methods
extern jint _jc_javax_swing_event_ListDataEvent$method$getIndex0$4a2aa7bb16839fe6(_jc_env *, struct _jc_javax_swing_event_ListDataEvent$object *) _JC_JCNI_ATTR;
extern jint _jc_javax_swing_event_ListDataEvent$method$getIndex1$c76868da218ce41e(_jc_env *, struct _jc_javax_swing_event_ListDataEvent$object *) _JC_JCNI_ATTR;
extern jint _jc_javax_swing_event_ListDataEvent$method$getType$74c20eac6b18d047(_jc_env *, struct _jc_javax_swing_event_ListDataEvent$object *) _JC_JCNI_ATTR;
extern void _jc_javax_swing_event_ListDataEvent$method$this$adc93fb6bf4cbffa(_jc_env *, struct _jc_javax_swing_event_ListDataEvent$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_javax_swing_event_ListDataEvent$method_info$getIndex0$4a2aa7bb16839fe6;
extern _jc_method _jc_javax_swing_event_ListDataEvent$method_info$getIndex1$c76868da218ce41e;
extern _jc_method _jc_javax_swing_event_ListDataEvent$method_info$getType$74c20eac6b18d047;
extern _jc_method _jc_javax_swing_event_ListDataEvent$method_info$this$adc93fb6bf4cbffa;

// Virtual methods structure
struct _jc_javax_swing_event_ListDataEvent$vmethods {
	jint	(*getIndex0$4a2aa7bb16839fe6)(_jc_env *, struct _jc_javax_swing_event_ListDataEvent$object *) _JC_JCNI_ATTR;
	jint	(*getIndex1$c76868da218ce41e)(_jc_env *, struct _jc_javax_swing_event_ListDataEvent$object *) _JC_JCNI_ATTR;
	jint	(*getType$74c20eac6b18d047)(_jc_env *, struct _jc_javax_swing_event_ListDataEvent$object *) _JC_JCNI_ATTR;
	void	(*this$adc93fb6bf4cbffa)(_jc_env *, struct _jc_javax_swing_event_ListDataEvent$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_javax_swing_event_ListDataEvent$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_util_EventObject$vmethods	java_util_EventObject;
	_jc_javax_swing_event_ListDataEvent$vmethods	javax_swing_event_ListDataEvent;
};

// Vtype
struct _jc_javax_swing_event_ListDataEvent$vtype {
	_jc_type			type;
	_jc_javax_swing_event_ListDataEvent$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_swing_event_ListDataEvent$sub_refs {
};

// Reference instance fields (object)
struct _jc_javax_swing_event_ListDataEvent$refs {
    _jc_javax_swing_event_ListDataEvent$sub_refs	javax_swing_event_ListDataEvent;
    _jc_java_util_EventObject$sub_refs	java_util_EventObject;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_swing_event_ListDataEvent$sub_nonrefs {
	jint	type;
	jint	index0;
	jint	index1;
};

// Non-reference instance fields (object)
struct _jc_javax_swing_event_ListDataEvent$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_util_EventObject$sub_nonrefs	java_util_EventObject;
    _jc_javax_swing_event_ListDataEvent$sub_nonrefs	javax_swing_event_ListDataEvent;
};

// Object instance structure
struct _jc_javax_swing_event_ListDataEvent$object {
	_jc_javax_swing_event_ListDataEvent$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_swing_event_ListDataEvent$vtype	*vtype;
	_jc_javax_swing_event_ListDataEvent$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_swing_event_ListDataEvent$vtype _jc_javax_swing_event_ListDataEvent$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_swing_event_ListDataEvent, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_swing_event_ListDataEvent$class_object;

#endif	/* _JC_javax_swing_event_ListDataEvent_H_ */
